#ifdef GL_ES
precision mediump float;
#endif

varying vec4 v_fragmentColor; // vertex shader传入，setColor设置的颜色
varying vec2 v_texCoord; // 纹理坐标

uniform vec2 textureSize; // 纹理大小（宽和高），为了计算周围各点的纹理坐标，必须传入它，因为纹理坐标范围是0~1
uniform vec3 GlowColor; 
uniform float GlowExpand; // 发光强度
uniform float GlowRange;  // 发光范围

const float sampleNum = 5;
// 思路：先过滤不透明点，然后按照角度找到这个范围内不透明的点的“不透明程度”，不透明程度越高，发光越多

void debug(float x)
{
    //vec4 col = texture2D(CC_Texture0, v_texCoord.xy);
    // if (v_texCoord.x > 0.5 && v_texCoord.y > 0.5) 
    {
        gl_FragColor = vec4(x/255.0, x/255.0, x/255.0, 1.1);
    }
}

// 获取像素周围不透明点的数量，可以指定范围和幅度
int getStrokeCount()
{
    vec2 unit = 1.0 / textureSize.xy;//单位坐标
    float r = GlowRange;
    float sampleStep = r / sampleNum;
    int count = 0;
    //遍历一个矩形，当前的坐标为中心点，遍历矩形中每个像素点的颜色
    for(float x = -r; x < r; x += sampleStep)
    {
        for(float y = -r; y < r; y += sampleStep)
        {
            vec4 col = texture2D(CC_Texture0, v_texCoord + vec2(x * unit.x, y * unit.y));
            if(col.a > 0.5)
            {
                count = count + 1;
            }
        }
    }
    return count;
}

void main()
{
    vec4 myC = texture2D(CC_Texture0, v_texCoord); // 正在处理的这个像素点的颜色
    if (myC.a > 0.5) // 不透明，不管，直接返回
    {
        gl_FragColor = v_fragmentColor * myC;
        return;
    }

    // 获取像素周围不透明点的数量
    int strokeCount = 0;
    strokeCount = getStrokeCount();
    
    float totalSample = (sampleNum * sampleNum * 2);
    float limit = totalSample * 0.8;
    if (strokeCount > limit)  //四周围至少有一个点是不透明的，这个点要设成描边颜色
    {
        myC.rgb = GlowColor * GlowExpand;
        myC.a = (strokeCount ) * GlowExpand / totalSample;
    }
    else
    {
        myC.rgb = GlowColor * strokeCount * GlowExpand / limit;
        myC.a = (strokeCount ) * GlowExpand / totalSample;
    }

    gl_FragColor = v_fragmentColor * myC;
}
